==> zio-aws-route53resolver_2.13-5.17.153.3-sources.jar: zio/aws/route53resolver/model/CreateFirewallRuleGroupResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateFirewallRuleGroupResponse(
    firewallRuleGroup: Option[zio.aws.route53resolver.model.FirewallRuleGroup] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse = {
    import CreateFirewallRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
      .builder()
      .optionallyWith(firewallRuleGroup.map(value => value.buildAwsValue()))(
        _.firewallRuleGroup
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse.ReadOnly =
    zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse
      .wrap(buildAwsValue())
}
object CreateFirewallRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse =
      zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse(
        firewallRuleGroup.map(value => value.asEditable)
      )
    def firewallRuleGroup
        : Option[zio.aws.route53resolver.model.FirewallRuleGroup.ReadOnly]
    def getFirewallRuleGroup: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRuleGroup.ReadOnly
    ] = AwsError.unwrapOptionField("firewallRuleGroup", firewallRuleGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
  ) extends zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse.ReadOnly {
    override val firewallRuleGroup
        : Option[zio.aws.route53resolver.model.FirewallRuleGroup.ReadOnly] =
      scala
        .Option(impl.firewallRuleGroup())
        .map(value =>
          zio.aws.route53resolver.model.FirewallRuleGroup.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
  ): zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_2.13-5.17.203.1-sources.jar: zio/aws/route53resolver/model/CreateFirewallRuleGroupResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateFirewallRuleGroupResponse(
    firewallRuleGroup: Optional[
      zio.aws.route53resolver.model.FirewallRuleGroup
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse = {
    import CreateFirewallRuleGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
      .builder()
      .optionallyWith(firewallRuleGroup.map(value => value.buildAwsValue()))(
        _.firewallRuleGroup
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse.ReadOnly =
    zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse
      .wrap(buildAwsValue())
}
object CreateFirewallRuleGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse =
      zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse(
        firewallRuleGroup.map(value => value.asEditable)
      )
    def firewallRuleGroup
        : Optional[zio.aws.route53resolver.model.FirewallRuleGroup.ReadOnly]
    def getFirewallRuleGroup: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.FirewallRuleGroup.ReadOnly
    ] = AwsError.unwrapOptionField("firewallRuleGroup", firewallRuleGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
  ) extends zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse.ReadOnly {
    override val firewallRuleGroup
        : Optional[zio.aws.route53resolver.model.FirewallRuleGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.firewallRuleGroup())
        .map(value =>
          zio.aws.route53resolver.model.FirewallRuleGroup.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.CreateFirewallRuleGroupResponse
  ): zio.aws.route53resolver.model.CreateFirewallRuleGroupResponse.ReadOnly =
    new Wrapper(impl)
}
